library(testthat)

test_check("kimisc")
test_examples()
